# Generated by Django 4.2.7 on 2023-12-04 22:19

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_prn", "0011_alter_endofstudy_device_created_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="endofstudy",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "End of Study",
                "verbose_name_plural": "End of Study",
            },
        ),
        migrations.AlterModelOptions(
            name="losstofollowup",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Loss to Follow Up",
                "verbose_name_plural": "Loss to Follow Up",
            },
        ),
        migrations.AlterModelOptions(
            name="offschedulecomm",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Off-schedule community-based integrated care",
                "verbose_name_plural": "Off-schedule community-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="offscheduleinte",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Off-schedule facility-based integrated care",
                "verbose_name_plural": "Off-schedule facility-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="onschedulecomm",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "On-schedule community-based integrated care",
                "verbose_name_plural": "On-schedule community-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="onscheduleinte",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "On-schedule facility-based integrated care",
                "verbose_name_plural": "On-schedule facility-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="protocolincident",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Protocol Incident",
                "verbose_name_plural": "Protocol Incident",
            },
        ),
        migrations.AlterModelOptions(
            name="subjecttransfer",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Subject Transfer",
                "verbose_name_plural": "Subject Transfers",
            },
        ),
        migrations.RemoveIndex(
            model_name="offschedulecomm",
            name="intecomm_pr_id_3f0fba_idx",
        ),
        migrations.RemoveIndex(
            model_name="offscheduleinte",
            name="intecomm_pr_id_494e36_idx",
        ),
        migrations.RemoveIndex(
            model_name="onschedulecomm",
            name="intecomm_pr_id_d4e5db_idx",
        ),
        migrations.RemoveIndex(
            model_name="onscheduleinte",
            name="intecomm_pr_id_6be831_idx",
        ),
        migrations.RemoveIndex(
            model_name="protocolincident",
            name="intecomm_pr_subject_73a582_idx",
        ),
        migrations.AddField(
            model_name="endofstudy",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="endofstudy",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalendofstudy",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalendofstudy",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicallosstofollowup",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicallosstofollowup",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicaloffschedulecomm",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicaloffschedulecomm",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicaloffscheduleinte",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicaloffscheduleinte",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalonschedulecomm",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalonschedulecomm",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalonscheduleinte",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalonscheduleinte",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalprotocolincident",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalprotocolincident",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectlocator",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectlocator",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjecttransfer",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjecttransfer",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="losstofollowup",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="losstofollowup",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="offschedulecomm",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="offschedulecomm",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="offscheduleinte",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="offscheduleinte",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="onschedulecomm",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="onschedulecomm",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="onscheduleinte",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="onscheduleinte",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="protocolincident",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="protocolincident",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="subjecttransfer",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="subjecttransfer",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddIndex(
            model_name="endofstudy",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_pr_action__f3bf58_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="endofstudy",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_f05824_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="endofstudy",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="intecomm_pr_user_mo_89a34d_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="endofstudy",
            index=models.Index(
                fields=["subject_identifier", "action_identifier", "site", "id"],
                name="intecomm_pr_subject_96eaef_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="losstofollowup",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_pr_subject_9a445d_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="losstofollowup",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_pr_action__415159_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="losstofollowup",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_dbd0f3_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="losstofollowup",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="intecomm_pr_user_mo_f0e202_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offschedulecomm",
            index=models.Index(
                fields=["subject_identifier", "offschedule_datetime", "site"],
                name="intecomm_pr_subject_51b057_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offschedulecomm",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_pr_action__c60fdc_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offschedulecomm",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_946b96_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="offschedulecomm",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="intecomm_pr_user_mo_593cbf_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offschedulecomm",
            index=models.Index(
                fields=[
                    "id",
                    "subject_identifier",
                    "action_identifier",
                    "offschedule_datetime",
                    "site",
                ],
                name="intecomm_pr_id_674324_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offscheduleinte",
            index=models.Index(
                fields=["subject_identifier", "offschedule_datetime", "site"],
                name="intecomm_pr_subject_86628b_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offscheduleinte",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_pr_action__3f16f3_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offscheduleinte",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_673c82_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="offscheduleinte",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="intecomm_pr_user_mo_8df27b_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="offscheduleinte",
            index=models.Index(
                fields=[
                    "id",
                    "subject_identifier",
                    "action_identifier",
                    "offschedule_datetime",
                    "site",
                ],
                name="intecomm_pr_id_2e2c54_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="onschedulecomm",
            index=models.Index(
                fields=["subject_identifier", "onschedule_datetime", "site"],
                name="intecomm_pr_subject_63aaaf_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="onschedulecomm",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_9288ba_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="onschedulecomm",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="intecomm_pr_user_mo_1e1ee6_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="onscheduleinte",
            index=models.Index(
                fields=["subject_identifier", "onschedule_datetime", "site"],
                name="intecomm_pr_subject_2dcd56_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="onscheduleinte",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_322d8f_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="onscheduleinte",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="intecomm_pr_user_mo_adb6ab_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="protocolincident",
            index=models.Index(
                fields=["subject_identifier", "action_identifier", "site"],
                name="intecomm_pr_subject_54092b_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="protocolincident",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_pr_subject_1a96f8_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="protocolincident",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_004622_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="protocolincident",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="intecomm_pr_user_mo_90fc4f_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="subjecttransfer",
            index=models.Index(
                fields=[
                    "id",
                    "subject_identifier",
                    "action_identifier",
                    "report_datetime",
                    "site",
                ],
                name="intecomm_pr_id_11fd1a_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="subjecttransfer",
            index=models.Index(
                fields=["modified", "created"], name="intecomm_pr_modifie_e233b6_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjecttransfer",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="intecomm_pr_user_mo_7d84b5_idx",
            ),
        ),
    ]
