# Generated by Django 4.2.7 on 2023-12-05 04:52

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_prn", "0012_alter_endofstudy_options_and_more"),
    ]

    operations = [
        migrations.RemoveIndex(
            model_name="subjecttransfer",
            name="intecomm_pr_id_11fd1a_idx",
        ),
        migrations.AddIndex(
            model_name="subjecttransfer",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_item",
                    "related_action_item",
                    "parent_action_item",
                ],
                name="intecomm_pr_action__7a579a_idx",
            ),
        ),
        migrations.AddIndex(
            model_name="subjecttransfer",
            index=models.Index(
                fields=["subject_identifier", "action_identifier", "report_datetime", "site"],
                name="intecomm_pr_subject_cef1b4_idx",
            ),
        ),
    ]
