# Generated by Django 4.2.1 on 2023-07-05 02:16

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_prn", "0006_alter_historicaloffschedulecomm_options_and_more"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="losstofollowup",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Loss to Follow Up",
                "verbose_name_plural": "Loss to Follow Up",
            },
        ),
        migrations.AlterModelOptions(
            name="offschedulecomm",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Off-schedule community-based integrated care",
                "verbose_name_plural": "Off-schedule community-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="offscheduleinte",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Off-schedule facility-based integrated care",
                "verbose_name_plural": "Off-schedule facility-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="onschedulecomm",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "On-schedule community-based integrated care",
                "verbose_name_plural": "On-schedule community-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="onscheduleinte",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "On-schedule facility-based integrated care",
                "verbose_name_plural": "On-schedule facility-based integrated care",
            },
        ),
        migrations.AlterModelOptions(
            name="protocolincident",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Protocol Incident",
                "verbose_name_plural": "Protocol Incident",
            },
        ),
        migrations.AlterModelOptions(
            name="subjecttransfer",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "get_latest_by": "modified",
                "ordering": ("-modified", "-created"),
                "verbose_name": "Subject Transfer",
                "verbose_name_plural": "Subject Transfers",
            },
        ),
    ]
