# Generated by Django 4.2.7 on 2023-12-05 03:45

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0129_alter_bloodresultsfbc_options_and_more"),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name="subjectrequisition",
            unique_together=set(),
        ),
        migrations.AddIndex(
            model_name="subjectrequisition",
            index=models.Index(
                fields=["subject_identifier"], name="intecomm_su_subject_e4994e_idx"
            ),
        ),
        migrations.AddConstraint(
            model_name="subjectrequisition",
            constraint=models.UniqueConstraint(
                fields=("panel", "subject_visit"),
                name="intecomm_subject_subjectrequisition_panel_uniq",
            ),
        ),
    ]
